.. _spkg_isoduration:

isoduration: Operations with ISO 8601 durations
===============================================

Description
-----------

Operations with ISO 8601 durations

License
-------

Upstream Contact
----------------

https://pypi.org/project/isoduration/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_arrow`
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    20.11.0

version_requirements.txt::

    isoduration

Equivalent System Packages
--------------------------

(none known)
